@@ -24,9 +24,9 @@ function(coords,z,method="Moran",nbclass=NULL){
      
      lst.res1<-rep(list(NA),nbclass)
      for(i in 1:length(breaks[,1])){
-        xt<-switch(pmatch(method,c("Moran","Geary"),nomatch=""),
-            "1"=try(moran.test(lst.z1[[i]], nb2listw(lst.nb1[[i]], style="W")),silent=TRUE),
-            "2"=try(geary.test(lst.z1[[i]], nb2listw(lst.nb1[[i]], style="W")),silent=TRUE),
+        xt<-switch(pmatch(method,c("Moran","Geary"),nomatch=3),
+            try(moran.test(lst.z1[[i]], nb2listw(lst.nb1[[i]], style="W")),silent=TRUE),
+            try(geary.test(lst.z1[[i]], nb2listw(lst.nb1[[i]], style="W")),silent=TRUE),
             stop("Method must be 'Moran' or 'Geary'"))
         if(inherits(xt,"try-error")) {stop("Bad selection of class breaks, try another one...")}
         else {
